import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const Notifications = data => {
  const notifications = data.notifications

  return (
    <div>
      <div className='header-nav-buttons'>
        <InertiaLink
          className='btn btn-dark'
          href='/eventpal/notifications/create'
        >
          <i className='fas fa-plus' />
          Create notification
        </InertiaLink>
      </div>

      <table className='table table-striped'>
        <thead>
          <tr className='text-left font-bold'>
            <th>#</th>
            <th>Event</th>
            <th>Status</th>
            <th>Title</th>
            <th>Message</th>
            <th>Send at</th>
            <th>Sent</th>
            <th>Total Sent</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {notifications.map(notification => (
            <tr key={notification.id}>
              <td>{notification.id}</td>
              <td>{notification.eventTitle}</td>
              <td>{notification.status}</td>
              <td>{notification.title}</td>
              <td>{notification.message}</td>
              <td>
                {notification.sendAt !== null
                  ? notification.sendAt
                  : 'Not scheduled'}
              </td>
              <td>
                {notification.sent === true ? (
                  <span className='badge badge-success'>&#10003;</span>
                ) : (
                  <span className='badge badge-danger'>X</span>
                )}
              </td>
              <td>
                {notification.totalSent > 0 ? notification.totalSent : 'None'}
              </td>
              <td>
                <InertiaLink
                  className='action-button'
                  href={`/eventpal/notifications/${notification.id}/edit`}
                  title='Edit notification'
                >
                  <span>
                    <i className='fa fa-pencil' />
                  </span>
                </InertiaLink>

                <InertiaLink
                  className='action-button'
                  href={`/eventpal/notifications/${notification.id}`}
                  title='Delete notification'
                  method='delete'
                >
                  <span>
                    <i className='far fa-trash' />
                  </span>
                </InertiaLink>
              </td>
            </tr>
          ))}
          {notifications.length === 0 && (
            <tr>
              <td className='border-t px-6 py-4' colSpan='9'>
                No notifications found
              </td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  )
}

// eslint-disable-next-line react/display-name
Notifications.layout = notification => (
  <Layout title='Notifications'>{notification}</Layout>
)

export default Notifications
