import React, { useState } from 'react';
import { Inertia } from '@inertiajs/inertia';
import { InertiaLink, usePage } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';
import SelectInput from '@/Shared/SelectInput';
import TextInput from '@/Shared/TextInput';
import TextAreaInput from '@/Shared/TextAreaInput';
import Button from '@/Shared/Button';

const QuizEditForm = () => {
  const { quiz, errors } = usePage();

  const [values, setValues] = useState({
    title: quiz.title || '',
    type: quiz.type || ''
  });

  function handleChange(e) {
    const key = e.target.name;
    const value = e.target.value;
    setValues(values => ({
      ...values,
      [key]: value
    }));
  }

  function handleSubmit(e) {
    e.preventDefault();
    Inertia.put(route('eventpal.quiz.update', quiz), values)
  }

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href="/eventpal/quiz"
        >
          <span><i className="fas fa-chevron-left"></i>Back to quiz list</span>
        </InertiaLink>
      </div>

      <div className="bg-white pt-3 pl-3">
        <form onSubmit={handleSubmit}>
          <div className="">
            <TextInput
              className="pb-3"
              label="Title"
              name="title"
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
            <SelectInput
              className="pb-3"
              label="Type"
              name="type"
              errors={errors.type}
              value={values.type}
              onChange={handleChange}
            >
              <option value="controlled">Controlled</option>
            </SelectInput>
          </div>
          <div className="">
            <Button
              type="submit"
              value="Submit"
              icon="fas fa-check"
              className="btn btn-dark"
            ></Button>
          </div>
        </form>
      </div>
    </div>
  )
}

QuizEditForm.layout = page => <Layout children={page} title="Edit Quiz" />

export default QuizEditForm
