import React, { useState } from 'react';
import { Inertia } from '@inertiajs/inertia';
import { InertiaLink } from '@inertiajs/inertia-react';
import Button from '@/Shared/Button';
import Layout from '@/Shared/Layout';

const Quizzes = (data) => {
  const quiz = data.quizzes;

  const [values, setValues] = useState({
    active: quiz.active || ''
  });

  function handleStartQuiz(e) {
    e.preventDefault();
    Inertia.post(route('quiz.activity.update'), values)
  }

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-dark"
          href={route('eventpal.quiz.create')}
        >
          <span><i className="fas fa-plus"></i>Create quiz</span>
        </InertiaLink>
      </div>

      <table className="table table-striped">
        <thead>
          <tr className="text-left font-bold">
            <th>#</th>
            <th>Title</th>
            <th>Questions</th>
            <th>Answers</th>
            <th>Status</th>
            <th>Controls</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {quiz.map(quiz => (
            <tr key={ quiz.id }>
              <td>{ quiz.id }</td>
              <td>{ quiz.title }</td>
              <td>{ quiz.questions }</td>
              <td>{ quiz.answers }</td>
              <td>
                {quiz.active > 0
                  ? <span className="badge badge-success">Active</span>
                  : <span className="badge badge-danger">Inactive</span>
                }
              </td>
                <td>
                    {quiz.active > 0
                        ?
                        <InertiaLink
                            className="action-button"
                            href={ route('eventpal.quiz.activity.de-activate', quiz) }
                            title="End quiz"
                        >
                            <span><i className="fas fa-times-circle"></i></span>
                        </InertiaLink>
                        :
                        <InertiaLink
                            className="action-button"
                            href={ route('eventpal.quiz.activity.activate', quiz) }
                            title="Start quiz"
                        >
                            <span><i className="fas fa-check"></i></span>
                        </InertiaLink>
                    }
                </td>
              <td>
                <InertiaLink
                  className="action-button"
                  href={route('eventpal.quiz.questions.index', quiz) }
                  title="View questions"
                >
                  <span><i className="fa fa-question-circle"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href={ route('eventpal.quiz.destroy', quiz) }
                  title="Delete"
                  method="delete"
                >
                  <span><i className="far fa-trash"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href={route('eventpal.quiz.edit', quiz)}
                  title="Edit"
                >
                  <span><i className="fa fa-pencil"></i></span>
                </InertiaLink>
              </td>
            </tr>
          ))}
          {quiz.length === 0 && (
            <tr>
              <td className="border-t px-6 py-4 text-center" colSpan="7">
                No quizzes found
              </td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  )
}

Quizzes.layout = page => <Layout children={page} title="Quizzes" />

export default Quizzes
