import React, { useState } from 'react';
import { Inertia } from '@inertiajs/inertia';
import { InertiaLink, usePage } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';
import SelectInput from '@/Shared/SelectInput';
import TextInput from '@/Shared/TextInput';
import TextAreaInput from '@/Shared/TextAreaInput';
import Button from '@/Shared/Button';

const QuizQuestionAnswerEditForm = () => {
  const { answer, errors } = usePage();

  const [values, setValues] = useState({
    title: answer.title || '',
    value: answer.value || '',
    is_correct: answer.isCorrect || 0,
  });

  function handleChange(e) {
    const key = e.target.name;
    const value = e.target.value;
    setValues(values => ({
      ...values,
      [key]: value,
    }));
  }

  function handleSubmit(e) {
    e.preventDefault();
    Inertia.patch(route('eventpal.quiz.questions.answers.update', [answer.quiz_id, answer.question_id, answer]), values)
  }

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href={route('eventpal.quiz.questions.answers.index', [answer.quiz_id, answer.question_id])}
        >
          <span><i className="fas fa-chevron-left"></i>Back to answers list</span>
        </InertiaLink>
      </div>

      <div className="bg-white pt-3 pl-3">
        <form onSubmit={handleSubmit}>
          <div className="">
            <TextInput
              className="pb-3"
              label="Title"
              name="title"
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
            <TextInput
              className="pb-3"
              label="Value"
              name="value"
              errors={errors.value}
              value={values.value}
              onChange={handleChange}
            />
              <SelectInput
                  className='pb-3'
                  label='Is Correct'
                  name='is_correct'
                  errors={errors.is_correct}
                  value={values.is_correct}
                  onChange={handleChange}
              >
                  <option key="Yes" value="1">
                      Yes
                  </option>
                  <option key="No" value="0">
                      No
                  </option>
              </SelectInput>
          </div>
          <div className="">
            <Button
              type="submit"
              value="Submit"
              icon="fas fa-check"
              className="btn btn-dark"
            ></Button>
          </div>
        </form>
      </div>
    </div>
  )
}

QuizQuestionAnswerEditForm.layout = page => <Layout children={page} title="Edit Answer" />

export default QuizQuestionAnswerEditForm
