import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import TextInput from '@/Shared/TextInput'
import Button from '@/Shared/Button'
import SelectInput from '../../../Shared/SelectInput'

const QuizQuestionCreateForm = () => {
  const { quiz, question, graphs, errors } = usePage()

  const [values, setValues] = useState({
    title: question.title || '',
    graph: question.graph || 'default',
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.put(route('eventpal.quiz.questions.update', [quiz, question]), values)
  }

  return (
    <div>
      <div className='header-nav-buttons'>
        <InertiaLink
          className='btn btn-light'
          href={route('eventpal.quiz.questions.index', quiz)}
        >
          <span>
            <i className='fas fa-chevron-left'></i>Back to question list
          </span>
        </InertiaLink>
      </div>

      <div className='bg-white pt-3 pl-3'>
        <form onSubmit={handleSubmit}>
          <div className=''>
            <TextInput
              className='pb-3'
              label='Title'
              name='title'
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
          </div>
          <div className=''>
            <SelectInput
              className='pb-3'
              label='Graph'
              name='graph'
              errors={errors.graph}
              value={values.graph}
              onChange={handleChange}
            >
              {Object.entries(graphs).map(([key, value]) => (
                <option key={key} value={value}>
                  {key}
                </option>
              ))}
            </SelectInput>
          </div>
          <div className=''>
            <Button
              type='submit'
              value='Submit'
              icon='fas fa-check'
              className='btn btn-dark'
            ></Button>
          </div>
        </form>
      </div>
    </div>
  )
}

QuizQuestionCreateForm.layout = page => (
  <Layout children={page} title='Create Quiz Question' />
)

export default QuizQuestionCreateForm
