import React from 'react';
import { InertiaLink } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';

const QuizQuestions = (data) => {
  const questions = data.questions
    const quiz = data.quiz

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href={route('eventpal.quiz.index')}
        >
          <span><i className="fas fa-chevron-left"></i>Back to Quiz list</span>
        </InertiaLink>

        <InertiaLink
          className="btn btn-dark"
          href={route('eventpal.quiz.questions.create', quiz)}
        >
          <span><i className="fas fa-plus"></i>Create Question</span>
        </InertiaLink>
      </div>

      <table className="table table-striped">
        <thead>
          <tr className="text-left font-bold">
            <th>Re-order</th>
            <th>#</th>
            <th>Question title</th>
            <th>Responses</th>
              <th>Status</th>
            <th>Question controls</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {questions.map(question => (
            <tr key={ question.id }>
              <td>
                <a className="action-button" href="#" title="TBC | Drag me to re-order">
                  <i className="fa fa-bars"></i>
                </a>
              </td>
              <td>{ question.id }</td>
              <td>{ question.title }</td>
              <td>{ question.responses }</td>
                <td>
                    {question.active > 0
                        ? <span className="badge badge-success">Active</span>
                        : <span className="badge badge-danger">Inactive</span>
                    }
                </td>
              <td>
                  {question.active ?
                      <InertiaLink
                          className="action-button"
                          href={ route('eventpal.quiz.question.activity.de-activate', [quiz, question]) }
                          title="End"
                      >
                          <span><i className="fas fa-times-circle"></i></span>
                      </InertiaLink>
                      :
                      <InertiaLink
                          className="action-button"
                          href={ route('eventpal.quiz.question.activity.activate', [quiz, question]) }
                          title="Start"
                      >
                          <span><i className="fa fa-play-circle"></i></span>
                      </InertiaLink>
                  }
                <InertiaLink
                  className="action-button"
                  href={route('eventpal.quiz.question.reveal-answer', [quiz, question])}
                  title="Reveal answer"
                >
                  <span><i className="fa fa-ban"></i></span>
                </InertiaLink>
                  <a
                      className="action-button"
                      href={ route('eventpal.quiz.question.results', [quiz, question]) }
                      title="View results"
                      target="_blank"
                  >
                      <span><i className="fa fa-bar-chart"></i></span>
                  </a>
              </td>
              <td>
                <InertiaLink
                  className="action-button"
                  href={route('eventpal.quiz.questions.answers.index', [quiz, question])}
                  title="View answers"
                >
                  <span><i className="fa fa-bars"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href="#"
                  title="View responses"
                >
                  <span><i className="fa fa-commenting-o"></i></span>
                </InertiaLink>
                  <InertiaLink
                      className="action-button"
                      href={route('eventpal.quiz.questions.edit', [quiz, question])}
                      title="Edit"
                  >
                      <span><i className="fa fa-edit"></i></span>
                  </InertiaLink>
              </td>
            </tr>
          ))}
          {questions.length === 0 && (
            <tr>
              <td className="border-t px-6 py-4" colSpan="6">
                No questions found
              </td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  )
}

QuizQuestions.layout = page => <Layout children={page} title="Question list" />

export default QuizQuestions
