import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const Speakers = data => {
  const speakers = data.speakers
  const bioLength = 100

  return (
    <div>
      <div className='header-nav-buttons'>
        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.speakers.create')}
        >
          <span>
            <i className='fas fa-plus' />
            Create speaker
          </span>
        </InertiaLink>
      </div>

      <table className='table table-striped'>
        <thead>
          <tr className='text-left font-bold'>
            <th>#</th>
            <th>Name</th>
            <th>Company</th>
            <th>Job title</th>
            <th>Bio</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {speakers.map(speaker => (
            <tr key={speaker.id}>
              <td>{speaker.id}</td>
              <td>{speaker.name}</td>
              <td>{speaker.company}</td>
              <td>{speaker.jobTitle}</td>
              <td>
                {speaker.bio.length > bioLength
                  ? speaker.bio.substring(0, bioLength - 3) + '...'
                  : speaker.bio.substring(0, bioLength)}
              </td>
              <td>
                <InertiaLink
                  className='action-button'
                  href={route('eventpal.speakers.edit', speaker)}
                  title='Edit speaker'
                >
                  <span>
                    <i className='fa fa-pencil' />
                  </span>
                </InertiaLink>

                <InertiaLink
                  className='action-button'
                  href={route('eventpal.speakers.delete', speaker)}
                  title='Delete speaker'
                  method='delete'
                >
                  <span>
                    <i className='far fa-trash' />
                  </span>
                </InertiaLink>
              </td>
            </tr>
          ))}
          {speakers.length === 0 && (
            <tr>
              <td className='border-t px-6 py-4' colSpan='4'>
                No speakers found
              </td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  )
}

// eslint-disable-next-line react/display-name
Speakers.layout = page => <Layout title='Speakers'>{page}</Layout>

export default Speakers
