import React, { useState } from 'react'
import PropTypes from 'prop-types'
import Select from 'react-select'

export default function ReactSelect({
  label,
  name,
  className,
  onChange,
  options = [],
  selectedOptions = [],
  errors = [],
  isDisabled = false,
  isSearchable = false,
  isMultiple = false,
}) {
  const [selected, setSelected] = useState(() => {
    if (selectedOptions.length === 0) {
      return []
    }

    return options.filter(option => {
      return selectedOptions.find(
        selectedOption => selectedOption === option.value,
      )
    })
  })

  function handleChange(selectedOptions) {
    setSelected(selectedOptions)
    onChange({
      target: {
        name: name,
        value: selectedOptions.map(selectedOption => {
          return selectedOption.value
        }),
      },
    })
  }

  return (
    <div className={`tw-w-2/5 ${className}`}>
      {label && (
        <label
          className='tw-block tw-text-gray-700 tw-text-sm tw-font-bold tw-mb-2'
          htmlFor={name}
        >
          {label}:
        </label>
      )}
      <Select
        value={selected}
        options={options}
        name={name}
        isDisabled={isDisabled}
        isSearchable={isSearchable}
        isMulti={isMultiple}
        onChange={handleChange}
      />
      {errors && <div className='form-error'>{errors[0]}</div>}
    </div>
  )
}

ReactSelect.propTypes = {
  className: PropTypes.string,
  errors: PropTypes.array,
  isDisabled: PropTypes.bool,
  isMultiple: PropTypes.bool,
  isSearchable: PropTypes.bool,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  options: PropTypes.array.isRequired,
  selectedOptions: PropTypes.array,
}
