import React from 'react'
import PropTypes from 'prop-types'

export default function SelectInput({
  label,
  name,
  className,
  children,
  errors = [],
  value = '',
  ...props
}) {
  return (
    <div className={className}>
      {label && (
        <label
          className='tw-block tw-text-gray-700 tw-text-sm tw-font-bold tw-mb-2'
          htmlFor={name}
        >
          {label}:
        </label>
      )}
      <select
        id={name}
        name={name}
        value={value}
        {...props}
        className={`tw-shadow tw-h-8 tw-border tw-rounded tw-w-2/5 tw-py-2 tw-px-3 tw-text-gray-700 tw-leading-tight focus:outline-none focus:shadow-outline ${
          errors.length ? 'error' : ''
        }`}
      >
        {children}
      </select>
      {errors && <div className='form-error'>{errors[0]}</div>}
    </div>
  )
}

SelectInput.propTypes = {
  children: PropTypes.array.isRequired,
  className: PropTypes.string,
  errors: PropTypes.array,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
}
