import React from 'react'
import PropTypes from 'prop-types'

export default function TextInput({
  label,
  name,
  className,
  errors = [],
  value,
  readOnly,
  ...props
}) {
  return (
    <div className={className}>
      {label && (
        <label
          className='tw-block tw-text-gray-700 tw-text-sm tw-font-bold tw-mb-2'
          htmlFor={name}
        >
          {label}:
        </label>
      )}
      <input
        id={name}
        name={name}
        value={value}
        {...props}
        className={`tw-shadow tw-appearance-none tw-border tw-rounded tw-w-2/5 tw-py-2 tw-px-3 tw-text-gray-700 tw-leading-tight focus:outline-none focus:shadow-outline ${
          errors.length ? 'error' : ''
        }`}
        readOnly={readOnly}
      />
      {errors && <div className='form-error'>{errors}</div>}
    </div>
  )
}

TextInput.propTypes = {
  className: PropTypes.string,
  errors: PropTypes.array,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  readOnly: PropTypes.bool,
  value: PropTypes.string,
}
