<?php

namespace Drp\EventPalAdmin\Http\Controllers\Quiz;

use Drp\EventPalAdmin\Http\Controllers\Controller;
use Drp\EventPalAdmin\Http\Requests\AnswerRequest;
use Drp\NativeEventApp\Models\Quiz;
use Drp\NativeEventApp\Models\QuizAnswer;
use Drp\NativeEventApp\Models\QuizQuestion;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use Inertia\Inertia;
use Inertia\Response;

class AnswerController extends Controller
{
    public function index(Quiz $quiz, QuizQuestion $question): Response
    {
        if ($question->answers()->count() === 0) {
            return Inertia::render('Quizzes/Questions/Answers/Index', [
                'quiz' => $quiz,
                'question' => $question,
                'answers' => [
                    ['quiz_id' => $quiz->id],
                ],
            ]);
        }

        return Inertia::render('Quizzes/Questions/Answers/Index', [
            'quiz' => $quiz,
            'question' => $question,
            'answers' => $question->answers()->get()
                ->transform(function ($answer) use ($quiz, $question) {
                    return [
                        'id' => $answer->id,
                        'quiz_id' => $quiz->id,
                        'question_id' => $question->id,
                        'title' => $answer->title,
                        'isCorrect' => $answer->is_correct,
                    ];
                }),
        ]);
    }

    public function create(Quiz $quiz, QuizQuestion $question): Response
    {
        return Inertia::render('Quizzes/Questions/Answers/Create', compact('quiz', 'question'));
    }

    public function store(AnswerRequest $request, Quiz $quiz, QuizQuestion $question): RedirectResponse
    {
        $question->answers()->create($request->all());

        Session::flash('success', 'Answer Created');

        return Redirect::route('eventpal.quiz.questions.answers.index', [$quiz, $question]);
    }

    public function edit(Quiz $quiz, QuizQuestion $question, QuizAnswer $answer): Response
    {
        return Inertia::render('Quizzes/Questions/Answers/Edit', [
            'answer' => [
                'id' => $answer->id,
                'quiz_id' => $quiz->id,
                'question_id' => $question->id,
                'title' => $answer->title,
                'value' => $answer->value,
                'isCorrect' => $answer->is_correct,
            ],
        ]);
    }

    public function update(AnswerRequest $request, Quiz $quiz, QuizQuestion $question, QuizAnswer $answer): RedirectResponse //phpcs:ignore
    {
        $answer->update($request->all());

        return Redirect::route('eventpal.quiz.questions.answers.index', compact('quiz', 'question'))
            ->with('success', 'Quiz answer updated.');
    }
}
