<?php

namespace Drp\EventPalAdmin\Http\Controllers\Quiz;

use Drp\EventPalAdmin\Http\Controllers\Controller;
use Drp\EventPalAdmin\Http\Requests\QuizQuestionRequest;
use Drp\NativeEventApp\Models\Quiz;
use Drp\NativeEventApp\Models\QuizQuestion;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use Inertia\Inertia;
use Inertia\Response;

class QuizQuestionController extends Controller
{
    public function index(Quiz $quiz): Response
    {
        return Inertia::render('Quizzes/Questions/Index', [
            'quiz' => $quiz,
            'questions' => $quiz->questions()->get()
                ->transform(function ($question) use ($quiz) {
                    return [
                        'id' => $question->id,
                        'quiz_id' => $quiz->id,
                        'title' => $question->title,
                        'responses' => $question->responses->count(),
                        'active' => $question->active,
                    ];
                }),
        ]);
    }

    public function create(Quiz $quiz): Response
    {
        return Inertia::render('Quizzes/Questions/Create', [
            'quiz' => $quiz,
            'graphs' => config('eventpal-admin.graphs'),
        ]);
    }

    public function store(QuizQuestionRequest $request, Quiz $quiz): RedirectResponse //phpcs:ignore
    {
        $quiz->questions()->create([
            'title' => $request->title,
            'graph' => $request->graph,
        ]);

        Session::flash('success', 'Quiz question created.');

        return Redirect::route('eventpal.quiz.questions.index', compact('quiz'));
    }

    public function edit(Quiz $quiz, QuizQuestion $question)
    {
        return Inertia::render('Quizzes/Questions/Edit', [
            'quiz' => $quiz,
            'question' => $question,
            'graphs' => config('eventpal-admin.graphs'),
        ]);
    }

    public function update(QuizQuestionRequest $request, Quiz $quiz, QuizQuestion $question)
    {
        $question->update($request->all());

        Session::flash('success', 'Question Updated');

        return Redirect::route('eventpal.quiz.questions.index', $quiz);
    }
}
