<?php

namespace Drp\EventPalAdmin\Http\Models;

use Drp\NativeEventApp\Models\QuizQuestion;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Auth;

class Question extends Model
{
    use SoftDeletes;

    protected $table = 'quiz_questions';

    protected $fillable = [
        'position',
        'quiz_id',
        'title',
    ];

    public function quiz(): BelongsTo
    {
        return $this->belongsTo(Quiz::class);
    }

    public function answers(): HasMany
    {
        return $this->hasMany(Answer::class);
    }

    public function responses(): HasMany
    {
        return $this->hasMany(Response::class);
    }

    public function scopeUnanswered(Builder $query): Builder
    {
        return $query->whereDoesntHave('responses', function (Builder $query): Builder {
            return $query->where('user_id', Auth::user()->id);
        });
    }

    public function correctAnswers(): HasMany
    {
        return $this->answers()->correct();
    }

    public function toNea(): QuizQuestion
    {
        return QuizQuestion::find($this->id);
    }
}
